@@ -263,7 +263,7 @@ function PeptographWidget(canvas, data, color_bar) {
         this.y_from_j(this.protein.i_source_view), 
         this.get_diff_width(0, this.data.n_res_in_view), 
         slice_height,
-        "#999");
+        "#AAA");
 
     //  highlight selected peptide
     var i_source_selected = this.protein.i_source_selected;
@@ -456,13 +456,15 @@ function Pepto(data) {
     this.spectrum_div = $("#spectrum");
     this.peptide_match_info_div = $("#peptide_match_info");
 
-    this.header_div.text(this.data['title']);
+    this.header_div.text(this.data.title);
+    document.title = this.data.title;
 
     // Build interactive page objects
     this.protein_list = new ProteinList(
         this.protein_control_div, this.protein_list_div, this.data);
 
-    this.peptograph_canvas = new CanvasWidget(this.peptograph_div, this.data.bg_color);
+    this.peptograph_div.css('width', '100%');
+    this.peptograph_canvas = new CanvasWidget(this.peptograph_div, this.data.bg_color, true);
     var width = this.peptograph_canvas.div.width();
     this.color_bar = new ColorBarWidget(
         this.peptograph_canvas, this.data['color_names'], this.data.canvas_font);
@@ -475,7 +477,7 @@ function Pepto(data) {
     this.peptograph_canvas.push(peptograph_widget);
 
     this.sequence_view = new SequenceView(this.sequence_div, this.data);
-    this.spectrum_canvas = new CanvasWidget(this.spectrum_div, this.data.bg_color);
+    this.spectrum_canvas = new CanvasWidget(this.spectrum_div, this.data.bg_color, true);
 
     this.spectrum_widget = new SpectrumWidget(this.spectrum_canvas, this.data);
     this.spectrum_canvas.push(this.spectrum_widget);
@@ -500,34 +502,57 @@ function Pepto(data) {
     var top =  get_bottom(this.protein_control_div);
     set_outer_height(this.protein_list_div, column1_height - top);
 
-    // move the central column to its right place
+    // resize column1_width if necessary
     var column1_width = get_outer_width(this.column1_div);
+    if (window_width < 1600) {
+      var default_width = 180;
+    } else {
+      var default_width = 450;
+    }
+    if (column1_width != default_width) {
+      column1_width = default_width;
+      set_outer_width(this.column1_div, column1_width);
+      this.protein_list.redraw_bars();
+    }
+
+    // move the central column to its right place
     set_left(this.column2_div, column1_width);
 
     // set heights and tops of central protein view
     set_outer_height(this.column2_div, main_height);
     var top = get_bottom(this.protein_info_div);
     set_top(this.peptograph_div, top);
-    var height = get_content_height(this.column2_div) - 1;
-    height += - top - get_outer_height(this.sequence_div)
+    var peptograph_height = get_content_height(this.column2_div) - 1;
+    peptograph_height += - top - get_outer_height(this.sequence_div)
     var n_source = this.data.controller.get_current_protein().sources.length;
     if (n_source < 5) {
       var fixed_height = this.color_bar.height*n_source + 10;
-      if (fixed_height < height) {
-        height = fixed_height;
+      if (fixed_height < peptograph_height) {
+        peptograph_height = fixed_height;
       }
     }
-    this.peptograph_canvas.set_height(height);
+    set_outer_height(this.peptograph_div, peptograph_height);
     top = get_bottom(this.peptograph_div);
     set_top(this.sequence_div, top);
 
-    // set widths of the central protein view
+    // check column3 variable width
     var column3_width = get_outer_width(this.column3_div)
+    if (window_width < 1600) {
+      var default_width = 240;
+    } else {
+      var default_width = 450;
+    }
+    if (column3_width != default_width) {
+      column3_width = default_width;
+      set_outer_width(this.column3_div, column3_width);
+    }
+
+    // set widths of the central protein view
     var width = window_width - column1_width - column3_width;
     set_outer_width(this.column2_div, width);
     width = get_content_width(this.column2_div);
-    this.peptograph_canvas.set_width(width);
     set_outer_width(this.sequence_div, width);
+    set_outer_width(this.peptograph_div, width);
 
     // move and resize the width right column 
     set_left(this.column3_div, window_width - column3_width);
@@ -538,7 +563,7 @@ function Pepto(data) {
     set_outer_height(this.peptide_list_div, Math.round(0.2*height));
     var top = get_bottom(this.peptide_list_div);
     set_top(this.spectrum_div, top);
-    this.spectrum_canvas.set_height(Math.round(0.2*height));
+    set_outer_height(this.spectrum_div, Math.round(0.2*height));
     var top = get_bottom(this.peptide_info_div) + this.spectrum_div.outerHeight(true);
     set_outer_height(this.ion_table_div, height - top);
   }
@@ -569,6 +594,8 @@ function Pepto(data) {
   this.init_data(data);
   this.init_widgets();
   this.register_callbacks();
+  block_bounce_except_for_touchscroll();
+
 }
 
 
